@@ -22,6 +22,8 @@ package main
 import (
 	"flag"
 	"fmt"
+	"math/rand"
+	"time"
 	"github.com/dustinkirkland/golang-petname"
 )
 
@@ -32,5 +34,6 @@ var (
 
 func main() {
 	flag.Parse()
+	rand.Seed(time.Now().UnixNano())
 	fmt.Println(petname.PetName(*words, *separator))
 }
